wallaroo.wallaroo_ml_ops_api_client.models.explainability_get_request_response_200 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.explainability_get_request_response_200

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5T = TypeVar("T", bound="ExplainabilityGetRequestResponse200")
     6
     7@attr.s(auto_attribs=True)
     8class ExplainabilityGetRequestResponse200:
     9    """
    10    """
    11
    12    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    13
    14
    15    def to_dict(self) -> Dict[str, Any]:
    16
    17        field_dict: Dict[str, Any] = {}
    18        field_dict.update(self.additional_properties)
    19        field_dict.update({
    20        })
    21
    22        return field_dict
    23
    24
    25
    26    @classmethod
    27    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    28        d = src_dict.copy()
    29        explainability_get_request_response_200 = cls(
    30        )
    31
    32        explainability_get_request_response_200.additional_properties = d
    33        return explainability_get_request_response_200
    34
    35    @property
    36    def additional_keys(self) -> List[str]:
    37        return list(self.additional_properties.keys())
    38
    39    def __getitem__(self, key: str) -> Any:
    40        return self.additional_properties[key]
    41
    42    def __setitem__(self, key: str, value: Any) -> None:
    43        self.additional_properties[key] = value
    44
    45    def __delitem__(self, key: str) -> None:
    46        del self.additional_properties[key]
    47
    48    def __contains__(self, key: str) -> bool:
    49        return key in self.additional_properties

@attr.s(auto_attribs=True)
class ExplainabilityGetRequestResponse200: View Source

     8@attr.s(auto_attribs=True)
     9class ExplainabilityGetRequestResponse200:
    10    """
    11    """
    12
    13    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    14
    15
    16    def to_dict(self) -> Dict[str, Any]:
    17
    18        field_dict: Dict[str, Any] = {}
    19        field_dict.update(self.additional_properties)
    20        field_dict.update({
    21        })
    22
    23        return field_dict
    24
    25
    26
    27    @classmethod
    28    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    29        d = src_dict.copy()
    30        explainability_get_request_response_200 = cls(
    31        )
    32
    33        explainability_get_request_response_200.additional_properties = d
    34        return explainability_get_request_response_200
    35
    36    @property
    37    def additional_keys(self) -> List[str]:
    38        return list(self.additional_properties.keys())
    39
    40    def __getitem__(self, key: str) -> Any:
    41        return self.additional_properties[key]
    42
    43    def __setitem__(self, key: str, value: Any) -> None:
    44        self.additional_properties[key] = value
    45
    46    def __delitem__(self, key: str) -> None:
    47        del self.additional_properties[key]
    48
    49    def __contains__(self, key: str) -> bool:
    50        return key in self.additional_properties

ExplainabilityGetRequestResponse200() View Source

    2def __init__(self, ):
    3    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class ExplainabilityGetRequestResponse200.

def to_dict(self) -> Dict[str, Any]: View Source

    16    def to_dict(self) -> Dict[str, Any]:
    17
    18        field_dict: Dict[str, Any] = {}
    19        field_dict.update(self.additional_properties)
    20        field_dict.update({
    21        })
    22
    23        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    27    @classmethod
    28    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    29        d = src_dict.copy()
    30        explainability_get_request_response_200 = cls(
    31        )
    32
    33        explainability_get_request_response_200.additional_properties = d
    34        return explainability_get_request_response_200

additional_keys: List[str]